==> jc-1.4.0.tar.gz: soot/javaToJimple/AssertStmtChecker.h <==
// public class soot.javaToJimple.AssertStmtChecker

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 534db787197439f0 polyglot_visit_NodeVisitor
// @dep_class 9000ee07025b8c98 soot_javaToJimple_AssertStmtChecker

// header file dependencies
// @dep_header polyglot_visit_NodeVisitor

#include "polyglot/visit/NodeVisitor.h"

#ifndef _JC_soot_javaToJimple_AssertStmtChecker_H_
#define _JC_soot_javaToJimple_AssertStmtChecker_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_polyglot_ast_Node$object;
struct _jc_polyglot_visit_NodeVisitor$object;

// Typedefs
typedef struct _jc_soot_javaToJimple_AssertStmtChecker$sub_refs	_jc_soot_javaToJimple_AssertStmtChecker$sub_refs;
typedef struct _jc_soot_javaToJimple_AssertStmtChecker$sub_nonrefs	_jc_soot_javaToJimple_AssertStmtChecker$sub_nonrefs;
typedef struct _jc_soot_javaToJimple_AssertStmtChecker$refs	_jc_soot_javaToJimple_AssertStmtChecker$refs;
typedef struct _jc_soot_javaToJimple_AssertStmtChecker$nonrefs	_jc_soot_javaToJimple_AssertStmtChecker$nonrefs;
typedef struct _jc_soot_javaToJimple_AssertStmtChecker$object	_jc_soot_javaToJimple_AssertStmtChecker$object;

typedef const struct _jc_soot_javaToJimple_AssertStmtChecker$vmethods	_jc_soot_javaToJimple_AssertStmtChecker$vmethods;
typedef const struct _jc_soot_javaToJimple_AssertStmtChecker$vtable	_jc_soot_javaToJimple_AssertStmtChecker$vtable;
typedef const struct _jc_soot_javaToJimple_AssertStmtChecker$vtype	_jc_soot_javaToJimple_AssertStmtChecker$vtype;

// Constructors
extern void _jc_soot_javaToJimple_AssertStmtChecker$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_javaToJimple_AssertStmtChecker$object *);

// Virtual methods
extern jboolean _jc_soot_javaToJimple_AssertStmtChecker$method$isHasAssert$015c30211b51712e(_jc_env *, struct _jc_soot_javaToJimple_AssertStmtChecker$object *);
extern struct _jc_object *_jc_soot_javaToJimple_AssertStmtChecker$method$leave$cf18a0cab654af63(_jc_env *, struct _jc_soot_javaToJimple_AssertStmtChecker$object *, struct _jc_object *, struct _jc_object *, struct _jc_polyglot_visit_NodeVisitor$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_javaToJimple_AssertStmtChecker$method_info$isHasAssert$015c30211b51712e;
extern _jc_method _jc_soot_javaToJimple_AssertStmtChecker$method_info$leave$cf18a0cab654af63;

// Virtual methods structure
struct _jc_soot_javaToJimple_AssertStmtChecker$vmethods {
	jboolean	(*isHasAssert$015c30211b51712e)(_jc_env *, struct _jc_soot_javaToJimple_AssertStmtChecker$object *);
	struct _jc_object	*(*leave$cf18a0cab654af63)(_jc_env *, struct _jc_soot_javaToJimple_AssertStmtChecker$object *, struct _jc_object *, struct _jc_object *, struct _jc_polyglot_visit_NodeVisitor$object *);
};

// Vtable
struct _jc_soot_javaToJimple_AssertStmtChecker$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_polyglot_visit_NodeVisitor$vmethods	polyglot_visit_NodeVisitor;
	_jc_soot_javaToJimple_AssertStmtChecker$vmethods	soot_javaToJimple_AssertStmtChecker;
};

// Vtype
struct _jc_soot_javaToJimple_AssertStmtChecker$vtype {
	_jc_type			type;
	_jc_soot_javaToJimple_AssertStmtChecker$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_javaToJimple_AssertStmtChecker$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_javaToJimple_AssertStmtChecker$refs {
    _jc_soot_javaToJimple_AssertStmtChecker$sub_refs	soot_javaToJimple_AssertStmtChecker;
    _jc_polyglot_visit_NodeVisitor$sub_refs	polyglot_visit_NodeVisitor;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_javaToJimple_AssertStmtChecker$sub_nonrefs {
	jboolean	hasAssert;
};

// Non-reference instance fields (object)
struct _jc_soot_javaToJimple_AssertStmtChecker$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_polyglot_visit_NodeVisitor$sub_nonrefs	polyglot_visit_NodeVisitor;
    _jc_soot_javaToJimple_AssertStmtChecker$sub_nonrefs	soot_javaToJimple_AssertStmtChecker;
};

// Object instance structure
struct _jc_soot_javaToJimple_AssertStmtChecker$object {
	_jc_soot_javaToJimple_AssertStmtChecker$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_javaToJimple_AssertStmtChecker$vtype	*vtype;
	_jc_soot_javaToJimple_AssertStmtChecker$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_javaToJimple_AssertStmtChecker$vtype _jc_soot_javaToJimple_AssertStmtChecker$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_javaToJimple_AssertStmtChecker, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_javaToJimple_AssertStmtChecker$class_object;

#endif	/* _JC_soot_javaToJimple_AssertStmtChecker_H_ */

==> jc-1.4.6.tar.gz: soot/javaToJimple/AssertStmtChecker.h <==
// public class soot.javaToJimple.AssertStmtChecker

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 534db787197439f0 polyglot_visit_NodeVisitor
// @dep_class 9000ee07025b8c98 soot_javaToJimple_AssertStmtChecker

// header file dependencies
// @dep_header polyglot_visit_NodeVisitor

#include "polyglot/visit/NodeVisitor.h"

#ifndef _JC_soot_javaToJimple_AssertStmtChecker_H_
#define _JC_soot_javaToJimple_AssertStmtChecker_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_polyglot_ast_Node$object;
struct _jc_polyglot_visit_NodeVisitor$object;

// Typedefs
typedef struct _jc_soot_javaToJimple_AssertStmtChecker$sub_refs	_jc_soot_javaToJimple_AssertStmtChecker$sub_refs;
typedef struct _jc_soot_javaToJimple_AssertStmtChecker$sub_nonrefs	_jc_soot_javaToJimple_AssertStmtChecker$sub_nonrefs;
typedef struct _jc_soot_javaToJimple_AssertStmtChecker$refs	_jc_soot_javaToJimple_AssertStmtChecker$refs;
typedef struct _jc_soot_javaToJimple_AssertStmtChecker$nonrefs	_jc_soot_javaToJimple_AssertStmtChecker$nonrefs;
typedef struct _jc_soot_javaToJimple_AssertStmtChecker$object	_jc_soot_javaToJimple_AssertStmtChecker$object;

typedef const struct _jc_soot_javaToJimple_AssertStmtChecker$vmethods	_jc_soot_javaToJimple_AssertStmtChecker$vmethods;
typedef const struct _jc_soot_javaToJimple_AssertStmtChecker$vtable	_jc_soot_javaToJimple_AssertStmtChecker$vtable;
typedef const struct _jc_soot_javaToJimple_AssertStmtChecker$vtype	_jc_soot_javaToJimple_AssertStmtChecker$vtype;

// Constructors
extern void _jc_soot_javaToJimple_AssertStmtChecker$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_javaToJimple_AssertStmtChecker$object *) _JC_JCNI_ATTR;

// Virtual methods
extern jboolean _jc_soot_javaToJimple_AssertStmtChecker$method$isHasAssert$015c30211b51712e(_jc_env *, struct _jc_soot_javaToJimple_AssertStmtChecker$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_soot_javaToJimple_AssertStmtChecker$method$leave$cf18a0cab654af63(_jc_env *, struct _jc_soot_javaToJimple_AssertStmtChecker$object *, struct _jc_object *, struct _jc_object *, struct _jc_polyglot_visit_NodeVisitor$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_javaToJimple_AssertStmtChecker$method_info$isHasAssert$015c30211b51712e;
extern _jc_method _jc_soot_javaToJimple_AssertStmtChecker$method_info$leave$cf18a0cab654af63;

// Virtual methods structure
struct _jc_soot_javaToJimple_AssertStmtChecker$vmethods {
	jboolean	(*isHasAssert$015c30211b51712e)(_jc_env *, struct _jc_soot_javaToJimple_AssertStmtChecker$object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*leave$cf18a0cab654af63)(_jc_env *, struct _jc_soot_javaToJimple_AssertStmtChecker$object *, struct _jc_object *, struct _jc_object *, struct _jc_polyglot_visit_NodeVisitor$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_javaToJimple_AssertStmtChecker$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_polyglot_visit_NodeVisitor$vmethods	polyglot_visit_NodeVisitor;
	_jc_soot_javaToJimple_AssertStmtChecker$vmethods	soot_javaToJimple_AssertStmtChecker;
};

// Vtype
struct _jc_soot_javaToJimple_AssertStmtChecker$vtype {
	_jc_type			type;
	_jc_soot_javaToJimple_AssertStmtChecker$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_javaToJimple_AssertStmtChecker$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_javaToJimple_AssertStmtChecker$refs {
    _jc_soot_javaToJimple_AssertStmtChecker$sub_refs	soot_javaToJimple_AssertStmtChecker;
    _jc_polyglot_visit_NodeVisitor$sub_refs	polyglot_visit_NodeVisitor;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_javaToJimple_AssertStmtChecker$sub_nonrefs {
	jboolean	hasAssert;
};

// Non-reference instance fields (object)
struct _jc_soot_javaToJimple_AssertStmtChecker$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_polyglot_visit_NodeVisitor$sub_nonrefs	polyglot_visit_NodeVisitor;
    _jc_soot_javaToJimple_AssertStmtChecker$sub_nonrefs	soot_javaToJimple_AssertStmtChecker;
};

// Object instance structure
struct _jc_soot_javaToJimple_AssertStmtChecker$object {
	_jc_soot_javaToJimple_AssertStmtChecker$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_javaToJimple_AssertStmtChecker$vtype	*vtype;
	_jc_soot_javaToJimple_AssertStmtChecker$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_javaToJimple_AssertStmtChecker$vtype _jc_soot_javaToJimple_AssertStmtChecker$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_javaToJimple_AssertStmtChecker, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_javaToJimple_AssertStmtChecker$class_object;

#endif	/* _JC_soot_javaToJimple_AssertStmtChecker_H_ */
